@@ -1,7 +1,9 @@
 package Software::Catalog::SW::firefox;
 
-our $DATE = '2019-10-26'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-10-02'; # DATE
+our $DIST = 'Software-Catalog-SW-firefox'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,21 +15,17 @@ with 'Software::Catalog::Role::Software';
 
 use Software::Catalog::Util qw(extract_from_url);
 
-sub meta {
-    return {
-        homepage_url => "https://mozilla.org/firefox",
-    };
-}
-
-sub latest_version {
+sub archive_info {
     my ($self, %args) = @_;
-
-    extract_from_url(
-        url => "https://www.mozilla.org/en-US/firefox/all/",
-        re  => qr/ data-latest-firefox="([^"]+)"/,
-    );
+    [200, "OK", {
+        programs => [
+            {name=>"firefox", path=>"/"},
+        ],
+    }];
 }
 
+sub available_versions { [501, "Not implemented"] }
+
 sub canon2native_arch_map {
     return +{
         'linux-x86' => 'linux',
@@ -54,16 +52,20 @@ sub download_url {
     # "https://archive.mozilla.org/pub/firefox/releases/62.0/source/"
 }
 
-sub archive_info {
+sub homepage_url { "https://mozilla.org/firefox" }
+
+sub is_dedicated_profile { 1 }
+
+sub latest_version {
     my ($self, %args) = @_;
-    [200, "OK", {
-        programs => [
-            {name=>"firefox", path=>"/"},
-        ],
-    }];
+
+    extract_from_url(
+        url => "https://www.mozilla.org/en-US/firefox/all/",
+        re  => qr/ data-latest-firefox="([^"]+)"/,
+    );
 }
 
-sub dedicated_profile { 1 }
+sub release_note { [501, "Not implemented"] }
 
 1;
 # ABSTRACT: Firefox
@@ -80,7 +82,7 @@ Software::Catalog::SW::firefox - Firefox
 
 =head1 VERSION
 
-This document describes version 0.006 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2019-10-26.
+This document describes version 0.007 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2020-10-02.
 
 =for Pod::Coverage ^(.+)$
 
@@ -106,7 +108,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
